==> dbpedia-ent-0.1.7.tar.gz: dbpedia-ent-0.1.7/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['dbpedia_ent',
 'dbpedia_ent.bp',
 'dbpedia_ent.dmo',
 'dbpedia_ent.dto',
 'dbpedia_ent.dto.ent',
 'dbpedia_ent.dto.ent.n1',
 'dbpedia_ent.dto.ent.n1.a',
 'dbpedia_ent.dto.ent.n1.b',
 'dbpedia_ent.dto.ent.n1.c',
 'dbpedia_ent.dto.ent.n1.d',
 'dbpedia_ent.dto.ent.n1.e',
 'dbpedia_ent.dto.ent.n1.f',
 'dbpedia_ent.dto.ent.n1.g',
 'dbpedia_ent.dto.ent.n1.h',
 'dbpedia_ent.dto.ent.n1.i',
 'dbpedia_ent.dto.ent.n1.j',
 'dbpedia_ent.dto.ent.n1.k',
 'dbpedia_ent.dto.ent.n1.l',
 'dbpedia_ent.dto.ent.n1.m',
 'dbpedia_ent.dto.ent.n1.n',
 'dbpedia_ent.dto.ent.n1.o',
 'dbpedia_ent.dto.ent.n1.p',
 'dbpedia_ent.dto.ent.n1.q',
 'dbpedia_ent.dto.ent.n1.r',
 'dbpedia_ent.dto.ent.n1.s',
 'dbpedia_ent.dto.ent.n1.t',
 'dbpedia_ent.dto.ent.n1.u',
 'dbpedia_ent.dto.ent.n1.v',
 'dbpedia_ent.dto.ent.n1.w',
 'dbpedia_ent.dto.ent.n1.x',
 'dbpedia_ent.dto.ent.n1.y',
 'dbpedia_ent.dto.ent.n1.z',
 'dbpedia_ent.dto.ent.n2.a',
 'dbpedia_ent.dto.ent.n2.b',
 'dbpedia_ent.dto.ent.n2.c',
 'dbpedia_ent.dto.ent.n2.d',
 'dbpedia_ent.dto.ent.n2.e',
 'dbpedia_ent.dto.ent.n2.f',
 'dbpedia_ent.dto.ent.n2.g',
 'dbpedia_ent.dto.ent.n2.h',
 'dbpedia_ent.dto.ent.n2.i',
 'dbpedia_ent.dto.ent.n2.j',
 'dbpedia_ent.dto.ent.n2.k',
 'dbpedia_ent.dto.ent.n2.l',
 'dbpedia_ent.dto.ent.n2.m',
 'dbpedia_ent.dto.ent.n2.n',
 'dbpedia_ent.dto.ent.n2.o',
 'dbpedia_ent.dto.ent.n2.p',
 'dbpedia_ent.dto.ent.n2.q',
 'dbpedia_ent.dto.ent.n2.r',
 'dbpedia_ent.dto.ent.n2.s',
 'dbpedia_ent.dto.ent.n2.t',
 'dbpedia_ent.dto.ent.n2.u',
 'dbpedia_ent.dto.ent.n2.v',
 'dbpedia_ent.dto.ent.n2.w',
 'dbpedia_ent.dto.ent.n2.x',
 'dbpedia_ent.dto.ent.n2.y',
 'dbpedia_ent.dto.ent.n2.z',
 'dbpedia_ent.dto.ent.n3.a',
 'dbpedia_ent.dto.ent.n3.b',
 'dbpedia_ent.dto.ent.n3.c',
 'dbpedia_ent.dto.ent.n3.d',
 'dbpedia_ent.dto.ent.n3.e',
 'dbpedia_ent.dto.ent.n3.f',
 'dbpedia_ent.dto.ent.n3.g',
 'dbpedia_ent.dto.ent.n3.h',
 'dbpedia_ent.dto.ent.n3.i',
 'dbpedia_ent.dto.ent.n3.j',
 'dbpedia_ent.dto.ent.n3.k',
 'dbpedia_ent.dto.ent.n3.l',
 'dbpedia_ent.dto.ent.n3.m',
 'dbpedia_ent.dto.ent.n3.n',
 'dbpedia_ent.dto.ent.n3.o',
 'dbpedia_ent.dto.ent.n3.p',
 'dbpedia_ent.dto.ent.n3.q',
 'dbpedia_ent.dto.ent.n3.r',
 'dbpedia_ent.dto.ent.n3.s',
 'dbpedia_ent.dto.ent.n3.t',
 'dbpedia_ent.dto.ent.n3.u',
 'dbpedia_ent.dto.ent.n3.v',
 'dbpedia_ent.dto.ent.n3.w',
 'dbpedia_ent.dto.ent.n3.x',
 'dbpedia_ent.dto.ent.n3.y',
 'dbpedia_ent.dto.ent.n3.z',
 'dbpedia_ent.dto.syn',
 'dbpedia_ent.dto.syn.n1',
 'dbpedia_ent.dto.syn.n1.a',
 'dbpedia_ent.dto.syn.n1.b',
 'dbpedia_ent.dto.syn.n1.c',
 'dbpedia_ent.dto.syn.n1.d',
 'dbpedia_ent.dto.syn.n1.e',
 'dbpedia_ent.dto.syn.n1.f',
 'dbpedia_ent.dto.syn.n1.g',
 'dbpedia_ent.dto.syn.n1.h',
 'dbpedia_ent.dto.syn.n1.i',
 'dbpedia_ent.dto.syn.n1.j',
 'dbpedia_ent.dto.syn.n1.k',
 'dbpedia_ent.dto.syn.n1.l',
 'dbpedia_ent.dto.syn.n1.m',
 'dbpedia_ent.dto.syn.n1.n',
 'dbpedia_ent.dto.syn.n1.o',
 'dbpedia_ent.dto.syn.n1.p',
 'dbpedia_ent.dto.syn.n1.q',
 'dbpedia_ent.dto.syn.n1.r',
 'dbpedia_ent.dto.syn.n1.s',
 'dbpedia_ent.dto.syn.n1.t',
 'dbpedia_ent.dto.syn.n1.u',
 'dbpedia_ent.dto.syn.n1.v',
 'dbpedia_ent.dto.syn.n1.w',
 'dbpedia_ent.dto.syn.n1.x',
 'dbpedia_ent.dto.syn.n1.y',
 'dbpedia_ent.dto.syn.n1.z',
 'dbpedia_ent.dto.syn.n2',
 'dbpedia_ent.dto.syn.n2.a',
 'dbpedia_ent.dto.syn.n2.b',
 'dbpedia_ent.dto.syn.n2.c',
 'dbpedia_ent.dto.syn.n2.d',
 'dbpedia_ent.dto.syn.n2.e',
 'dbpedia_ent.dto.syn.n2.f',
 'dbpedia_ent.dto.syn.n2.g',
 'dbpedia_ent.dto.syn.n2.h',
 'dbpedia_ent.dto.syn.n2.i',
 'dbpedia_ent.dto.syn.n2.j',
 'dbpedia_ent.dto.syn.n2.k',
 'dbpedia_ent.dto.syn.n2.l',
 'dbpedia_ent.dto.syn.n2.m',
 'dbpedia_ent.dto.syn.n2.n',
 'dbpedia_ent.dto.syn.n2.o',
 'dbpedia_ent.dto.syn.n2.p',
 'dbpedia_ent.dto.syn.n2.q',
 'dbpedia_ent.dto.syn.n2.r',
 'dbpedia_ent.dto.syn.n2.s',
 'dbpedia_ent.dto.syn.n2.t',
 'dbpedia_ent.dto.syn.n2.u',
 'dbpedia_ent.dto.syn.n2.v',
 'dbpedia_ent.dto.syn.n2.w',
 'dbpedia_ent.dto.syn.n2.x',
 'dbpedia_ent.dto.syn.n2.y',
 'dbpedia_ent.dto.syn.n2.z',
 'dbpedia_ent.dto.syn.n3',
 'dbpedia_ent.dto.syn.n3.a',
 'dbpedia_ent.dto.syn.n3.b',
 'dbpedia_ent.dto.syn.n3.c',
 'dbpedia_ent.dto.syn.n3.d',
 'dbpedia_ent.dto.syn.n3.e',
 'dbpedia_ent.dto.syn.n3.f',
 'dbpedia_ent.dto.syn.n3.g',
 'dbpedia_ent.dto.syn.n3.h',
 'dbpedia_ent.dto.syn.n3.i',
 'dbpedia_ent.dto.syn.n3.j',
 'dbpedia_ent.dto.syn.n3.k',
 'dbpedia_ent.dto.syn.n3.l',
 'dbpedia_ent.dto.syn.n3.m',
 'dbpedia_ent.dto.syn.n3.n',
 'dbpedia_ent.dto.syn.n3.o',
 'dbpedia_ent.dto.syn.n3.p',
 'dbpedia_ent.dto.syn.n3.q',
 'dbpedia_ent.dto.syn.n3.r',
 'dbpedia_ent.dto.syn.n3.s',
 'dbpedia_ent.dto.syn.n3.t',
 'dbpedia_ent.dto.syn.n3.u',
 'dbpedia_ent.dto.syn.n3.v',
 'dbpedia_ent.dto.syn.n3.w',
 'dbpedia_ent.dto.syn.n3.x',
 'dbpedia_ent.dto.syn.n3.y',
 'dbpedia_ent.dto.syn.n3.z',
 'dbpedia_ent.svc']

package_data = \
{'': ['*']}

install_requires = \
['baseblock', 'unicodedata2']

setup_kwargs = {
    'name': 'dbpedia-ent',
    'version': '0.1.7',
    'description': 'Static dbPedia Entities for Fast Lookups',
    'long_description': None,
    'author': 'Craig Trim',
    'author_email': 'craig.trim@causalitylink.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '==3.8.5',
}


setup(**setup_kwargs)

==> dbpedia-ent-0.1.9.tar.gz: dbpedia-ent-0.1.9/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['dbpedia_ent',
 'dbpedia_ent.bp',
 'dbpedia_ent.dmo',
 'dbpedia_ent.dto',
 'dbpedia_ent.dto.ent',
 'dbpedia_ent.dto.ent.n1',
 'dbpedia_ent.dto.ent.n1.a',
 'dbpedia_ent.dto.ent.n1.b',
 'dbpedia_ent.dto.ent.n1.c',
 'dbpedia_ent.dto.ent.n1.d',
 'dbpedia_ent.dto.ent.n1.e',
 'dbpedia_ent.dto.ent.n1.f',
 'dbpedia_ent.dto.ent.n1.g',
 'dbpedia_ent.dto.ent.n1.h',
 'dbpedia_ent.dto.ent.n1.i',
 'dbpedia_ent.dto.ent.n1.j',
 'dbpedia_ent.dto.ent.n1.k',
 'dbpedia_ent.dto.ent.n1.l',
 'dbpedia_ent.dto.ent.n1.m',
 'dbpedia_ent.dto.ent.n1.n',
 'dbpedia_ent.dto.ent.n1.o',
 'dbpedia_ent.dto.ent.n1.p',
 'dbpedia_ent.dto.ent.n1.q',
 'dbpedia_ent.dto.ent.n1.r',
 'dbpedia_ent.dto.ent.n1.s',
 'dbpedia_ent.dto.ent.n1.t',
 'dbpedia_ent.dto.ent.n1.u',
 'dbpedia_ent.dto.ent.n1.v',
 'dbpedia_ent.dto.ent.n1.w',
 'dbpedia_ent.dto.ent.n1.x',
 'dbpedia_ent.dto.ent.n1.y',
 'dbpedia_ent.dto.ent.n1.z',
 'dbpedia_ent.dto.ent.n2.a',
 'dbpedia_ent.dto.ent.n2.b',
 'dbpedia_ent.dto.ent.n2.c',
 'dbpedia_ent.dto.ent.n2.d',
 'dbpedia_ent.dto.ent.n2.e',
 'dbpedia_ent.dto.ent.n2.f',
 'dbpedia_ent.dto.ent.n2.g',
 'dbpedia_ent.dto.ent.n2.h',
 'dbpedia_ent.dto.ent.n2.i',
 'dbpedia_ent.dto.ent.n2.j',
 'dbpedia_ent.dto.ent.n2.k',
 'dbpedia_ent.dto.ent.n2.l',
 'dbpedia_ent.dto.ent.n2.m',
 'dbpedia_ent.dto.ent.n2.n',
 'dbpedia_ent.dto.ent.n2.o',
 'dbpedia_ent.dto.ent.n2.p',
 'dbpedia_ent.dto.ent.n2.q',
 'dbpedia_ent.dto.ent.n2.r',
 'dbpedia_ent.dto.ent.n2.s',
 'dbpedia_ent.dto.ent.n2.t',
 'dbpedia_ent.dto.ent.n2.u',
 'dbpedia_ent.dto.ent.n2.v',
 'dbpedia_ent.dto.ent.n2.w',
 'dbpedia_ent.dto.ent.n2.x',
 'dbpedia_ent.dto.ent.n2.y',
 'dbpedia_ent.dto.ent.n2.z',
 'dbpedia_ent.dto.ent.n3.a',
 'dbpedia_ent.dto.ent.n3.b',
 'dbpedia_ent.dto.ent.n3.c',
 'dbpedia_ent.dto.ent.n3.d',
 'dbpedia_ent.dto.ent.n3.e',
 'dbpedia_ent.dto.ent.n3.f',
 'dbpedia_ent.dto.ent.n3.g',
 'dbpedia_ent.dto.ent.n3.h',
 'dbpedia_ent.dto.ent.n3.i',
 'dbpedia_ent.dto.ent.n3.j',
 'dbpedia_ent.dto.ent.n3.k',
 'dbpedia_ent.dto.ent.n3.l',
 'dbpedia_ent.dto.ent.n3.m',
 'dbpedia_ent.dto.ent.n3.n',
 'dbpedia_ent.dto.ent.n3.o',
 'dbpedia_ent.dto.ent.n3.p',
 'dbpedia_ent.dto.ent.n3.q',
 'dbpedia_ent.dto.ent.n3.r',
 'dbpedia_ent.dto.ent.n3.s',
 'dbpedia_ent.dto.ent.n3.t',
 'dbpedia_ent.dto.ent.n3.u',
 'dbpedia_ent.dto.ent.n3.v',
 'dbpedia_ent.dto.ent.n3.w',
 'dbpedia_ent.dto.ent.n3.x',
 'dbpedia_ent.dto.ent.n3.y',
 'dbpedia_ent.dto.ent.n3.z',
 'dbpedia_ent.dto.syn',
 'dbpedia_ent.dto.syn.n1',
 'dbpedia_ent.dto.syn.n1.a',
 'dbpedia_ent.dto.syn.n1.b',
 'dbpedia_ent.dto.syn.n1.c',
 'dbpedia_ent.dto.syn.n1.d',
 'dbpedia_ent.dto.syn.n1.e',
 'dbpedia_ent.dto.syn.n1.f',
 'dbpedia_ent.dto.syn.n1.g',
 'dbpedia_ent.dto.syn.n1.h',
 'dbpedia_ent.dto.syn.n1.i',
 'dbpedia_ent.dto.syn.n1.j',
 'dbpedia_ent.dto.syn.n1.k',
 'dbpedia_ent.dto.syn.n1.l',
 'dbpedia_ent.dto.syn.n1.m',
 'dbpedia_ent.dto.syn.n1.n',
 'dbpedia_ent.dto.syn.n1.o',
 'dbpedia_ent.dto.syn.n1.p',
 'dbpedia_ent.dto.syn.n1.q',
 'dbpedia_ent.dto.syn.n1.r',
 'dbpedia_ent.dto.syn.n1.s',
 'dbpedia_ent.dto.syn.n1.t',
 'dbpedia_ent.dto.syn.n1.u',
 'dbpedia_ent.dto.syn.n1.v',
 'dbpedia_ent.dto.syn.n1.w',
 'dbpedia_ent.dto.syn.n1.x',
 'dbpedia_ent.dto.syn.n1.y',
 'dbpedia_ent.dto.syn.n1.z',
 'dbpedia_ent.dto.syn.n2',
 'dbpedia_ent.dto.syn.n2.a',
 'dbpedia_ent.dto.syn.n2.b',
 'dbpedia_ent.dto.syn.n2.c',
 'dbpedia_ent.dto.syn.n2.d',
 'dbpedia_ent.dto.syn.n2.e',
 'dbpedia_ent.dto.syn.n2.f',
 'dbpedia_ent.dto.syn.n2.g',
 'dbpedia_ent.dto.syn.n2.h',
 'dbpedia_ent.dto.syn.n2.i',
 'dbpedia_ent.dto.syn.n2.j',
 'dbpedia_ent.dto.syn.n2.k',
 'dbpedia_ent.dto.syn.n2.l',
 'dbpedia_ent.dto.syn.n2.m',
 'dbpedia_ent.dto.syn.n2.n',
 'dbpedia_ent.dto.syn.n2.o',
 'dbpedia_ent.dto.syn.n2.p',
 'dbpedia_ent.dto.syn.n2.q',
 'dbpedia_ent.dto.syn.n2.r',
 'dbpedia_ent.dto.syn.n2.s',
 'dbpedia_ent.dto.syn.n2.t',
 'dbpedia_ent.dto.syn.n2.u',
 'dbpedia_ent.dto.syn.n2.v',
 'dbpedia_ent.dto.syn.n2.w',
 'dbpedia_ent.dto.syn.n2.x',
 'dbpedia_ent.dto.syn.n2.y',
 'dbpedia_ent.dto.syn.n2.z',
 'dbpedia_ent.dto.syn.n3',
 'dbpedia_ent.dto.syn.n3.a',
 'dbpedia_ent.dto.syn.n3.b',
 'dbpedia_ent.dto.syn.n3.c',
 'dbpedia_ent.dto.syn.n3.d',
 'dbpedia_ent.dto.syn.n3.e',
 'dbpedia_ent.dto.syn.n3.f',
 'dbpedia_ent.dto.syn.n3.g',
 'dbpedia_ent.dto.syn.n3.h',
 'dbpedia_ent.dto.syn.n3.i',
 'dbpedia_ent.dto.syn.n3.j',
 'dbpedia_ent.dto.syn.n3.k',
 'dbpedia_ent.dto.syn.n3.l',
 'dbpedia_ent.dto.syn.n3.m',
 'dbpedia_ent.dto.syn.n3.n',
 'dbpedia_ent.dto.syn.n3.o',
 'dbpedia_ent.dto.syn.n3.p',
 'dbpedia_ent.dto.syn.n3.q',
 'dbpedia_ent.dto.syn.n3.r',
 'dbpedia_ent.dto.syn.n3.s',
 'dbpedia_ent.dto.syn.n3.t',
 'dbpedia_ent.dto.syn.n3.u',
 'dbpedia_ent.dto.syn.n3.v',
 'dbpedia_ent.dto.syn.n3.w',
 'dbpedia_ent.dto.syn.n3.x',
 'dbpedia_ent.dto.syn.n3.y',
 'dbpedia_ent.dto.syn.n3.z',
 'dbpedia_ent.svc']

package_data = \
{'': ['*']}

install_requires = \
['baseblock', 'unicodedata2']

setup_kwargs = {
    'name': 'dbpedia-ent',
    'version': '0.1.9',
    'description': 'Static dbPedia Entities for Fast Lookups',
    'long_description': None,
    'author': 'Craig Trim',
    'author_email': 'craigtrim@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8.5,<4.0.0',
}


setup(**setup_kwargs)
